* This is a simple static model with additions:
*  (1) health care affects effective labour supply and utility
*  (2) government expenditures on each good (incl. health care) fixed in value
*      (measured in fe terms (ER)) or in real terms (see GCMult(i))

* By Martine Rutten

$offlisting
$include data.gms

Parameter
GCMult(i)     Government consumption multiplier

* Parameters associated with effective labour supplies and waiting lists
Eta0          Non participation rate if health care does not affect WL
Fbar          Fixed endowment of factor f by household h
Upsilon(i,f)  Share parameter health composite
Epsilon(f)    Waiting list elasticity;

* government expenditures on each good (incl. health care) fixed in value
GCMult(i)    = 1;

* Waiting list elasticity values
Epsilon(f)   = 2;

* with HC = 1 in benchmark, eta0 is also benchmark non-participation rate
Eta0("skill")= 0.0289;
Eta0("unsk") = 0.0434;
Fbar(h,f)    = SAM(h,f) * 1/(1-Eta0(f));

* Share of 'health' determined by public (NHS) care:
Upsilon("NHS","Unsk") = 0.960;
Upsilon("NHS","Skill")= 0.834;

* Share of 'health' determined by private (PHC) care:
Upsilon("PHC","Unsk")  = 1-Upsilon("NHS","Unsk") ;
Upsilon("PHC","Skill") = 1-Upsilon("NHS","Skill");

* if there is a parent file that includes this file then solution and solver
* status file not printed
$if not "%system.incparent%"=="" option sysout=off;option solprint=off;

$ontext
$model:SCGE
$sectors:
         X(i)           ! production of sector i
         CET(i)         ! armington aggregate demand (domestic and export)
         ST             ! total (real) savings
         M(i)$VM(i)     ! imports of commodity i
         E(i)$VE(i)     ! exports of commodity i
$commodities:
         PQ(i)          ! producer price commodity i
         PD(i)          ! domestic consumption price commodity i
         PE(i)$VE(i)    ! export price commodity i
         PM(i)$VM(i)    ! import price commodity i
         PF(f)          ! price of factor f
         PS             ! price of savings
         ER             ! exchange rate (price of foreign exchange)
         PYG            ! price of artificial commodity real tax income
         PTR            ! price of artificial commodity transfer
$consumers:
         YGP            ! government income production tax
         YGC            ! government income consumption tax
         YGE            ! government income employment tax
         TR             ! transfers to households
         Y(h)           ! household income

* Specify auxiliary variables that are solved in the $constraint block
* The constraints are applied by using the label R: in endowment field
* the auxiliary variable enters as multiplier
$auxiliary:
         GOVCONS(i)$(USE(i,"GOVT"))    ! Real government consumption
         HC(f)                         ! Health composite
         EPR(f)                        ! Effective participation rate

$prod:X(i)       s:0  t:1  va:1
      O:PQ(j)    Q:Make(j,i)                 A:YGP T:PTAX(i) P:(1-PTAX0(i))
      I:PF(f)    Q:(Use(f,i)/(1+ETAX0(f)))   A:YGE T:ETAX(f) P:(1+ETAX0(f))  va:
      I:PD(j)    Q:Use(j,i)

$prod:CET(i)     s:0  t:2  arm:2
      O:PD(i)    Q:VD(i)                     A:YGC T:CTAX(i) P:(VDN(i)/VD(i))
      O:PE(i)    Q:VE(i)
      I:PQ(i)    Q:(sum(j, Make(i,j)))       arm:
      I:PM(i)    Q:VM(i)                     arm:
      I:PD("7")  Q:Make(i,"margin")

$prod:ST         s:0
      O:PS       Q:(sum(i,Use(i,"inv")))
      I:PD(i)    Q:Use(i,"inv")

$prod:M(i)$VM(i)
      O:PM(i)    Q:VM(i)
      I:ER       Q:VM(i)

$prod:E(i)$VE(i)
      O:ER       Q:VE(i)
      I:PE(i)    Q:VE(i)

$demand:YGP
      D:PYG     Q:SAM("tax","act")

$demand:YGC
      D:PYG     Q:SAM("tax","com")

$demand:YGE
      D:PYG     Q:(sum(f,SAM("tax",f)))

$demand:TR                   s:1
      E:PYG                  Q:(Mult*SAM("gov","tax"))
      E:PD(i)$Use(i,"GOVT")  Q:(-Mult*Use(i,"GOVT"))         R:GOVCONS(i)
      D:PTR                  Q:(sum(h,SAM(h,"gov")))
      E:ER                   Q:(Mult*(SAM("gov","row")-SAM("row","gov")))

$demand:Y(h)                 s:1
      E:PF(f)                Q:(Mult*Fbar(h,f))              R:EPR(f)
      D:PD(i)                Q:Use(i,h)
      D:PS                   Q:SAM("inv",h)
      E:PTR                  Q:(Mult*SAM(h,"gov"))

$report:
      V:U(h)     W:Y(h)
      V:FD(f,i)  I:PF(f)         prod:X(i)
      V:N(j,i)   I:PD(j)         prod:X(i)
      V:QS(i)    I:PQ(i)         prod:CET(i)
      V:QTM(i)   I:PD("7")       prod:CET(i)
      V:INV(i)   I:PD(i)         prod:ST
      V:C(i,h)   D:PD(i)         demand:Y(h)
      V:S(h)     D:PS            demand:Y(h)

* GCMult(i)=0: govt exp on good i are fixed in real terms
* GCMult(i)>0: govt exp on good i are fixed in value (ER) and equal to:
* PD(i)*Mult*Use(i,"GOVT")*GCMult(i)*ER/PD(i), so (real) government
* consumption of good i equals: Mult*Use(i,"GOVT")*GCMult(i)*ER/PD(i)
* Fixed in terms of another price (here numeraire ER) to prevent choice of /
* change in numeraire to affect outcome. Rewrite constraint:PD(i)*GOVCONS(i)=
* ER* GCMULT(i): lhs is fixed in ER terms, GCMULT(i)>1 simulates rise exp on i
$constraint:GOVCONS(i)$Use(i,"GOVT")
         GOVCONS(i) =E= GCMult(i) * ER/PD(i) + 1$(GCMult(i) = 0);

* Specification of health composite as a function of NHS and PHC
$constraint:HC(f)
         HC(f)      =E= prod[i, (CET(i)/Mult)**Upsilon(i,f)];

* Effective participation rate = 1- non-participation rate
$constraint:EPR(f)
         EPR(f)     =E= 1-Eta0(f)/(HC(f)**Epsilon(f));

$offtext
$sysinclude mpsgeset SCGE

* check benchmark replication:
SCGE.ITERLIM = 0        ;
HC.L(f)      = 1        ;
EPR.L(f)     = 1-Eta0(f);
GOVCONS.L(i) = 1        ;
ER.FX        = 1        ;
$include SCGE.GEN
solve SCGE using mcp;
abort$(SCGE.OBJVAL > 1e-3) "benchmark replication failed", SCGE.OBJVAL;

* store utility to quickly save variable values, changes and % changes
$libinclude store these X CET ST M E PQ PD PE PM PF PS ER YGP YGC YGE TR Y
$libinclude store these GOVCONS HC EPR U FD N QS QTM INV C S

* EV = change utility for each household
$libinclude store calc Utility (h)= u.l(h)*[sum[i,Use(i,h)]+Sam('inv',h)];

* total EV (sum of each household's EV + govt cons (incl. public health care):
$libinclude store calc Welfare = sum[h,utility(h)] + sum[i, GOVCONS.L(i)*Use(i,"govt")];

* total EV (sum of household EV's excluding public good provisioning):
$libinclude store calc WelfareEx = sum[h,utility(h)];

Table alphaG(i,h) Share of household h in public good provisioning of i
         HSE1     HSE2    HSE3    HSE4    HSE5
9        0.176    0.064   0.054   0.370   0.336
NHS      0.251    0.087   0.076   0.306   0.280
11       0.176    0.064   0.054   0.370   0.336;

* EV, including welfare changes related to public goods (incl. health care):
$libinclude store calc Utility1 (h) = utility(h) + sum[i, alphaG(i,h)*GOVCONS.L(i)*Use(i,"govt")];

* Household income from factors and transfers
$libinclude store calc YHF (h,f) = PF.l(f)*Fbar(h,f)*EPR.l(f);
$libinclude store calc YHTR (h)  = PTR.l* SAM(h,"gov");

* Variables waiting list (WL), effective endowments (FE) and
* non-participation rate (eta):
$libinclude store calc FE (h,f)= Fbar(h,f)*EPR.l(f)  ;
$libinclude store calc WL (h,f)= Fbar(h,f)-FE(h,f)   ;
$libinclude store calc eta (f) = 1-EPR.l(f)          ;

* Government expenditures
$libinclude store calc GEXP (i) = GOVCONS.L(i)*Use(i,"govt")*PD.l(i);

* set the model name and base scenario in the store utility:
$libinclude store setmodel SCGE
$libinclude store base
$libinclude store setbase base

* numeraire check:
SCGE.ITERLIM = 1000;
ER.FX        = 1.5;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(ST.l-1) > 1e-5) "numeraire check failed", SCGE.OBJVAL;

* homegeneity check:
ER.FX = 1;
MULT  = 2;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(PS.l-1) > 1e-5) "homegeneity check failed", SCGE.OBJVAL;
MULT  = 1;

* if there is a parent file that includes this file then do not include following
* simulations and display statement, but go directly to the label end
$if not "%system.incparent%"=="" $goto end

* test an increase in health expenditure, govt exp all goods i fixed in value

GCMult("NHS") = 1.1;
$batinclude solve healthexp
GCMult("NHS") = 1;

* display the variable values, changes and % changes
$libinclude store display changes percent

$label end