* Same as basemodel but with possibility of sector-specific factors and migration
* Foreign workers (FW) earn the health care specific skilled wage.
* The income (YF) can be sent home in the form of remittances (REM) or kept
* in the economy in the form of foreign worker transfers (FWT) at an artifical
* price (PFWT). These are distributed over households according to each
* household's share (alphaf) of the endowment of hc spec skilled labour (yielding
* YFW). Foreign skilled workers in health care benefit in the same way from health
* improvements as their domestic counterpart (yielding effective endowment FWE
* and waiting list FWL).

* By Martine Rutten

$offlisting
$include data.gms

Parameter
GCMult(i)     Government consumption multiplier
Eta0          Non participation rate if health care does not affect WL
Fbar          Fixed endowment of factor f by household h
SFbar         Fixed endowment of sector-specific factor by household h
Upsilon(i,f)  Share parameter health composite
Epsilon(f)    Waiting list elasticity;

GCMult(i)    = 1;

Epsilon(f)   = 2;
Eta0("skill")= 0.0289;
Eta0("unsk") = 0.0434;

Upsilon("NHS","Unsk") = 0.960;
Upsilon("NHS","Skill")= 0.834;
Upsilon("PHC","Unsk") = 1-Upsilon("NHS","Unsk") ;
Upsilon("PHC","Skill")= 1-Upsilon("NHS","Skill");

Parameter FSHARE(f,i) Share of sector-specific factor in factor use sector;
FSHARE(f,i)            = 0   ;
FSHARE("skill","10")   = 0.85;

Fbar(h,f)    = SAM(h,f);
SFbar(h,f,i) = (Fbar(h,f)/sum(g,Fbar(g,f)))*FSHARE(f,i)*Use(f,i)/(1+ETAX0(f));
Fbar(h,f)    = Fbar(h,f)-sum(i, SFbar(h,f,i));
Fbar(h,f)    = Fbar(h,f)*1/(1-Eta0(f))       ;
SFbar(h,f,i) = SFbar(h,f,i)*1/(1-Eta0(f))    ;

Parameter Mfactor(f,i) Use of mobile factor by sector
          Sfactor(f,i) Use of sector-specific factor;
Sfactor(f,i) = Use(f,i)*FSHARE(f,i)/(1+ETAX0(f))    ;
Mfactor(f,i) = Use(f,i)*(1-FSHARE(f,i))/(1+ETAX0(f));

Parameter

alphaf(h)  share of income foreign worker to household h
FW(f,i)    foreign worker of type f employed in sector i
alphar     remittances of income foreign workers to ROW as share;

FW(f,i)                 = 0;
alphar                  = 0;
alphaf(h)               = 0;

$if not "%system.incparent%"=="" option sysout=off; option solprint=off;

$ontext
$model:SCGE
$sectors:
         X(i)           ! production of sector i
         CET(i)         ! armington aggregate demand (domestic and export)
         ST             ! total (real) savings
         M(i)$VM(i)     ! imports of commodity i
         E(i)$VE(i)     ! exports of commodity i
$commodities:
         PQ(i)          ! producer price commodity i
         PD(i)          ! domestic consumption price commodity i
         PE(i)$VE(i)    ! export price commodity i
         PM(i)$VM(i)    ! import price commodity i
         PF(f)          ! price of factor f
         PFS(f,i)$fshare(f,i)    ! sector specific factors
         PS                      ! price of savings
         ER             ! exchange rate (price of foreign exchange)
         PYG            ! price of artificial commodity 'real tax income'
         PTR            ! price of artificial commodity transfer
         PFWT$(SUM(i,SUM(f,FW(f,i))) AND (1-alphar)) ! price of art.comm. for. worker transfer
$consumers:
         YGP                           ! government income production tax
         YGC                           ! government income consumption tax
         YGE                           ! government income employment tax
         TR                            ! transfers to households
         Y(h)                          ! household income
         YF$SUM(i,SUM(f,FW(f,i)))      ! income of foreign workers
$auxiliary:
         GOVCONS(i)$(USE(i,"GOVT"))    ! Real government consumption
         HC(f)                         ! Health composite
         EPR(f)                        ! Effective participation rate

$prod:X(i)       s:0  t:1  va:1
      O:PQ(j)    Q:Make(j,i)     A:YGP T:PTAX(i) P:(1-PTAX0(i))
      I:PF(f)    Q:Mfactor(f,i)  A:YGE T:ETAX(f) P:(1+ETAX0(f))  va:
      I:PFS(f,i) Q:Sfactor(f,i)  A:YGE T:ETAX(f) P:(1+ETAX0(f))  va:
      I:PD(j)    Q:Use(j,i)

$prod:CET(i)     s:0  t:2  arm:2
      O:PD(i)    Q:VD(i)         A:YGC  T:CTAX(i) P:(VDN(i)/VD(i))
      O:PE(i)    Q:VE(i)
      I:PQ(i)    Q:(sum(j, Make(i,j))) arm:
      I:PM(i)    Q:VM(i)               arm:
      I:PD("7")  Q:Make(i,"Margin")

$prod:ST         s:0
      O:PS       Q:(sum(i,Use(i,"inv")))
      I:PD(i)    Q:Use(i,"inv")

$prod:M(i)$VM(i)
      O:PM(i)    Q:VM(i)
      I:ER       Q:VM(i)

$prod:E(i)$VE(i)
      O:ER       Q:VE(i)
      I:PE(i)    Q:VE(i)

$demand:YGP
      D:PYG     Q:SAM("tax","act")

$demand:YGC
      D:PYG     Q:SAM("tax","com")

$demand:YGE
      D:PYG     Q:(sum(f,SAM("tax",f)))

$demand:TR                   s:1
      E:PYG                  Q:(Mult*SAM("gov","tax"))
      E:PD(i)$Use(i,"GOVT")  Q:(-Mult*Use(i,"GOVT"))     R:GOVCONS(i)
      D:PTR                  Q:(sum(h,SAM(h,"gov")))
      E:ER                   Q:(Mult*(SAM("gov","row")-SAM("row","gov")))

$demand:Y(h)                 s:1
      E:PF(f)                Q:(Mult*Fbar(h,f))          R:EPR(f)
      E:PFS(f,i)             Q:(Mult*SFbar(h,f,i))       R:EPR(f)
      D:PD(i)                Q:Use(i,h)
      D:PS                   Q:SAM("inv",h)
      E:PTR                  Q:(Mult*SAM(h,"gov"))
      E:PFWT$(1-alphar)      Q:(Mult*alphaf(h))

$demand:YF$SUM(i,SUM(f,FW(f,i)))      s:1
      E:PFS(f,i)$FW(f,i)              Q:(Mult*FW(f,i))   R:EPR(f)
      D:ER                            Q:alphar
      D:PFWT                          Q:(1-alphar)

$report:
      V:U(h)     W:Y(h)
      V:FD(f,i)  I:PF(f)         prod:X(i)
      V:SFD(f,i) I:PFS(f,i)      prod:X(i)
      V:N(j,i)   I:PD(j)         prod:X(i)
      V:QS(i)    I:PQ(i)         prod:CET(i)
      V:QTM(i)   I:PD("7")       prod:CET(i)
      V:INV(i)   I:PD(i)         prod:ST
      V:C(i,h)   D:PD(i)         demand:Y(h)
      V:S(h)     D:PS            demand:Y(h)
      V:REM      D:ER            demand:YF
      V:FWT      D:PFWT          demand:YF

$constraint:GOVCONS(i)$Use(i,"GOVT")
GOVCONS(i)$(GCMult(i)<>2)+PFS("SKILL","10")$(GCMult(i)=2)=E=
1$(GCMult(i)=0)+(ER/PD(i))$(GCMult(i)=1)+ER$(GCMult(i)=2);

$constraint:HC(f)
         HC(f)      =E= prod[i, (CET(i)/Mult)**Upsilon(i,f)];
$constraint:EPR(f)
         EPR(f)     =E= 1-Eta0(f)/(HC(f)**Epsilon(f));
$offtext
$sysinclude mpsgeset SCGE

* check benchmark replication:
SCGE.ITERLIM = 0        ;
HC.L(f)      = 1        ;
EPR.L(f)     = 1-Eta0(f);
GOVCONS.L(i) = 1        ;
ER.FX        = 1        ;
$include SCGE.GEN
solve SCGE using mcp;
abort$(SCGE.OBJVAL > 1e-3) "benchmark replication failed", SCGE.OBJVAL;

$libinclude store these X CET ST M E PQ PD PE PM PF PS ER YGP YGC YGE TR Y PFWT YF
$libinclude store these GOVCONS HC EPR U PFS FD SFD N QS QTM INV C S REM FWT

$libinclude store calc utility (h)  = u.l(h)*[sum[i,Use(i,h)]+Sam('inv',h)];
$libinclude store calc welfare      = sum[h,utility(h)] + sum[i, GOVCONS.L(i)*Use(i,"govt")];
$libinclude store calc WelfareEx    = sum[h,utility(h)];

Table alphaG(i,h) Share of household h in public good provisioning of i
         HSE1     HSE2    HSE3    HSE4    HSE5
9        0.176    0.064   0.054   0.370   0.336
NHS      0.251    0.087   0.076   0.306   0.280
11       0.176    0.064   0.054   0.370   0.336;

$libinclude store calc Utility1 (h) = utility(h) + sum[i, alphaG(i,h)*GOVCONS.L(i)*Use(i,"govt")];

$libinclude store calc YHF (h,f) = PF.l(f)*Fbar(h,f)*EPR.l(f);
$libinclude store calc YHFS (h,f,i) = PFS.l(f,i)*SFbar(h,f,i)*EPR.l(f);
$libinclude store calc YHTR (h)  = PTR.l* SAM(h,"gov");

$libinclude store calc FE (h,f) = Fbar(h,f)*EPR.l(f)  ;
$libinclude store calc WL (h,f) = Fbar(h,f)-FE(h,f)   ;
$libinclude store calc eta (f)  = 1-EPR.l(f)          ;

$libinclude store calc SFE (h,f,i) = SFbar(h,f,i)*EPR.l(f)  ;
$libinclude store calc SWL (h,f,i) = SFbar(h,f,i)-SFE(h,f,i);

$libinclude store calc GEXP (i) = GOVCONS.L(i)*Use(i,"govt")*PD.l(i);

* Foreign worker income to household h, effective endowment (FWE), waiting list
* (FWL) and trade surplus TS (=TS1). The trade surplus is financed by government
* and fixed in value so it shouldn't change. Note also that M and E are
* normalised to 1 in benchmark so need to multiply by their benchmark values.
$libinclude store calc TF (h)    = alphaf(h)*FWT.l*PFWT.l;
$libinclude store calc FWE (f,i) = FW(f,i)*EPR.l(f);
$libinclude store calc FWL (f,i) = FW(f,i)-FWE(f,i);
$libinclude store calc TS        = YGP.l+YGC.l+YGE.l-TR.l-sum(i,GEXP(i));
$libinclude store calc TS1       = sum(i, E.l(i)*VE(i)-M.l(i)*VM(i))-REM.l;

$libinclude store setmodel SCGE
$libinclude store base
$libinclude store setbase base

* numeraire check:
SCGE.ITERLIM = 1000;
ER.FX        = 1.5;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(ST.l-1) > 1e-5) "numeraire check failed", SCGE.OBJVAL;

* homegeneity check:
ER.FX = 1;
MULT  = 2;
$include SCGE.GEN
solve SCGE using mcp;
abort$(abs(PS.l-1) > 1e-5) "homegeneity check failed", SCGE.OBJVAL;
MULT  = 1;

$if not "%system.incparent%"=="" $goto end

* EXPERIMENT 1
* import skilled labour in health care: 10% of hc spec skilled labour
* if relevant income foreign workers is distributed over households
* according to share of spec factor.
*    GCMULT("NHS") = 2: government consumption of health care
*    in real terms is endogenous and adjusts so that skilled wage in health care
*    does not change.
*    GCMULT("NHS") = 1, then the NHS budget is fixed in nominal terms and skilled wage is allowed
*    to fall so that real NHS provision levels may increase
* NB: without health effects? Then specify epsilon(f) = 0.

FW("SKILL","10")        = 0.1*SUM(h,SFbar(h,"SKILL","10"));
alphaf(h)               = SFbar(h,"SKILL","10")/SUM(g,SFbar(g,"SKILL","10"));
display alphaf;

* no remittances abroad
alphar                   = 0;
GCMULT("NHS")            = 2;
* GCMULT("NHS")           = 1;
$batinclude solve EXP1_0

* half of income foreign workers is remitted abroad
alphar = 0.5;
$batinclude solve EXP1_50

* all income foreign workers is remitted abroad
alphar = 1;
$batinclude solve EXP1_100

FW(f,i)                 = 0;
alphar                  = 0;
alphaf(h)               = 0;

$libinclude store display changes percent

$label end